.. _examples_gallery:

**Examples**
============

Explore our gallery of examples demonstrating the usage of DeepPeak. These examples range from general API usage to specific applications, presented in a tutorial format to guide users through practical implementations.

.. toctree::
    :maxdepth: 2
    :hidden:

    /gallery/index.rst